==> hyades.source_3.0.1.1_20041013_1609.zip: org/eclipse/hyades/logging/events/cbe/util/EventMessages_ko.java <==
package org.eclipse.hyades.logging.events.cbe.util;

import java.util.ListResourceBundle;
import org.eclipse.hyades.logging.events.cbe.util.EventMessages;

/**********************************************************************
 * Copyright (c) 2004 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

/**
 * Korean resource bundle.
 * 
 * @author Paul E. Slauenwhite
 * @version 1.0.1
 * @since 1.0.1
 */
public class EventMessages_ko extends ListResourceBundle {

    /**************************************************************************
    * Implements java.util.ListResourceBundle.getContents().
    * @see java.util.ListResourceBundle#getContents
    **************************************************************************/

    public Object[][] getContents() {
        return contents_;
    }

    /**************************************************************************
    * Resource table
    **************************************************************************/
    private final static Object[][] contents_ = { { EventMessages.LOG_INVALID_JNDI_REFERENCE_EXC_, "IWAT0187E \uc9c0\uc815\ub41c JNDI \uc774\ub984\uc5d0\uc11c \ud655\ubcf4\ud55c \ucc38\uc870\uac00 \uc774\ubca4\ud2b8 \ud329\ud1a0\ub9ac\uc5d0 \ub300\ud55c \ucc38\uc870\uac00 \uc544\ub2d9\ub2c8\ub2e4.\nJNDI \uc774\ub984: {0}" }, {
        EventMessages.LOG_FAILED_TO_SERIALIZE_CONTENT_HANDLER_EXC_, "IWAT0188E \uc774\ubca4\ud2b8 \ub0b4\uc6a9 \ud578\ub4e4\ub7ec\ub97c 2\uc9c4 \ud615\uc2dd\uc73c\ub85c \ubcc0\ud658\ud560 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4.\n\ucd94\uac00 \uc815\ubcf4(\uc788\ub294 \uacbd\uc6b0): {0}" }, {
        EventMessages.LOG_FAILED_TO_DESERIALIZE_CONTENT_HANDLER_EXC_, "IWAT0189E 2\uc9c4 \ud615\uc2dd\uc5d0\uc11c \uc774 JNDI \uc774\ub984\uc73c\ub85c \ucc38\uc870\ud558\ub294 \uc774\ubca4\ud2b8 \ub0b4\uc6a9 \ud578\ub4e4\ub7ec\ub85c \ub2e4\uc2dc \ubcc0\ud658\ud560 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4. \nJNDI \uc774\ub984: {0} \n\ucd94\uac00 \uc815\ubcf4(\uc788\uc744 \uacbd\uc6b0): {1}" }, {
        EventMessages.LOG_INVALID_GLOBAL_INSTANCE_ID_EXC_, "IWAT0190E \uc9c0\uc815\ub41c Common Base Event \ud2b9\uc131\uc758 \uc774\ubca4\ud2b8 ID\ub294 \uc601\ubb38\uc790\ub85c \uc2dc\uc791\ud574\uc57c \ud569\ub2c8\ub2e4. \n\ud2b9\uc131: {0} \nID: {1} " }, {
        EventMessages.LOG_VALUE_ARRAY_SIZE_MISMATCH_EXC_, "IWAT0191E \uc9c0\uc815\ub41c \ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c\uac00 \ud574\ub2f9 \uac12 \ubc30\uc5f4 \uc548\uc5d0 \ud558\ub098\uc758 \uc694\uc18c\ub9cc \ud544\uc694\ud55c \uc720\ud615\uc774\ub098 \uc5ec\ub7ec \uac1c\uc758 \uac12\uc774 \uc788\uc2b5\ub2c8\ub2e4. \n\ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c: {1}\n\uc720\ud615: {2} \n\uac12\uc758 \uc218: {0} " }, {
        EventMessages.LOG_INVALID_TYPE_CONVERSION_EXC_, "IWAT0192E \ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c\uc758 \uac12\uc744 \uc9c0\uc815\ud55c \uc720\ud615\uc73c\ub85c \ubcc0\ud658\ud560 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4. \n\ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c: {2} \n\uac12: {0} \n\uc720\ud615: {1}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_TYPE_EXC_, "IWAT0193E \ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c\uc5d0 \uc720\ud6a8\ud558\uc9c0 \uc54a\uc740 \uc694\uc18c\uac00 \uc788\uc2b5\ub2c8\ub2e4. \n\ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c: {0}\n\uc720\ud615: {1}" }, {
        EventMessages.LOG_EXTENDED_DATA_VALUE_NULL_EXC_, "IWAT0194E \ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c\uc5d0 \ub110\uac12\uc774 \ub4e4\uc5b4 \uc788\uc2b5\ub2c8\ub2e4. \uc720\ud615\uc774 \ubc30\uc5f4\uc774\uba74 \ud558\ub098 \uc774\uc0c1\uc758 \uc694\uc18c\uac00 \ub110(null)\uc785\ub2c8\ub2e4. \n\ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c: {0} \n\uc720\ud615: {1} " }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_BOOLEAN_EXC_, "IWAT0195E \ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c\uc5d0 \uc720\ud6a8\ud558\uc9c0 \uc54a\uc740 \ubd80\uc6b8 \ubb38\uc790\uc5f4\uc774 \ub4e4\uc5b4 \uc788\uc2b5\ub2c8\ub2e4. \n\ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c: {0}\n\uc720\ud615: {1} \n\ubb38\uc790\uc5f4: {2}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_DATE_EXC_, "IWAT0196E \ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c\uc5d0 \uc720\ud6a8\ud558\uc9c0 \uc54a\uc740 dateTime \ubb38\uc790\uc5f4\uc774 \ub4e4\uc5b4 \uc788\uc2b5\ub2c8\ub2e4. \n\ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c: {0}\nType: {1}\ndateTime \ubb38\uc790\uc5f4: {2}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_HEX_BINARY_1_EXC_, "IWAT0197E \ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c\uc758 hexValue \ud2b9\uc131 \uc694\uc18c\uc5d0\ub294 \uc9dd\uc218 \uac1c\uc758 \ubb38\uc790\uac00 \ub4e4\uc5b4 \uc788\uc5b4\uc57c \ud569\ub2c8\ub2e4. \n\ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c: {0} \n\uc720\ud615: {1} \n\uac12: {2} " }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_HEX_BINARY_2_EXC_, "IWAT0198E \ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c\uc758 hexValue \ud2b9\uc131\uc5d0 16\uc9c4\uc774 \uc544\ub2cc \ubb38\uc790\uac00 \ub4e4\uc5b4 \uc788\uc2b5\ub2c8\ub2e4. \n\ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c \uc774\ub984: {0} \n\uc720\ud615: {1} \n\uac12: {2} \n\ube4416\uc9c4 \ubb38\uc790: {3} " }, {
        EventMessages.LOG_INVALID_SITUATION_TYPE_EXC_, "IWAT0199E \uc9c0\uc815\ub41c \ud2b9\uc131\uc758 \uac12\uc774 \uc720\ud6a8\ud558\uc9c0 \uc54a\uc2b5\ub2c8\ub2e4. \n\ud2b9\uc131: {0} \n\uac12: {1} \n\uc720\ud6a8\uac12: {2} " }, {
        EventMessages.LOG_INVALID_CREATION_TIME_EXC_, "IWAT0200E \uc9c0\uc815\ub41c \ud2b9\uc131\uc758 dateTime \uac12\uc744 \uad6c\ubb38 \ubd84\uc11d\ud560 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4. \n\ud2b9\uc131: {0} \n\uac12: {1} " }, {
        EventMessages.LOG_INVALID_LIST_ELEMENT_LENGTH_EXC_, "IWAT0201E \uc9c0\uc815\ub41c \ud2b9\uc131\uc5d0 \uc788\ub294 \uc694\uc18c \uae38\uc774\uac00 \ucd5c\ub300 \ubb38\uc790 \uc218\ub97c \ucd08\uacfc\ud569\ub2c8\ub2e4. \n\ud2b9\uc131: {1} \n\uc694\uc18c: {0} \n\ucd5c\ub300 \uae38\uc774: {2} " }, {
        EventMessages.LOG_VALUE_OUT_OF_RANGE_EXC_, "IWAT0202E \ud2b9\uc131 \uac12\uc774 \uc720\ud6a8\ud55c \ubc94\uc704 \ubc16\uc5d0 \uc788\uc2b5\ub2c8\ub2e4. \n\ud2b9\uc131: {1} \n\uac12: {0} \n\uc720\ud6a8 \ubc94\uc704: {2} - {3} " }, {
        EventMessages.LOG_MISSING_REQUIRED_ATTRIBUTE_EXC_, "IWAT0203E Common Base Event\uc5d0 \ud544\uc218 \ud2b9\uc131\uc774 \ub204\ub77d\ub418\uc5c8\uc2b5\ub2c8\ub2e4. \n\ud2b9\uc131: {0} " }, {
        EventMessages.LOG_MUTUALLY_EXCLUSIVE_ATTRIBUTES_EXC_, "IWAT0204E Common Base Event\uc5d0 \ud568\uaed8 \uc0ac\uc6a9\ud560 \uc218 \uc5c6\ub294 \ud2b9\uc131\uc774 \uc788\uc2b5\ub2c8\ub2e4. \n\ud2b9\uc131 1: {0} \n\ud2b9\uc131 2: {1} " }, {
        EventMessages.LOG_INVALID_VERSION_EXC_, "IWAT0205E {0} \ud2b9\uc131\uc758 \ubc84\uc804\uc774 \uc720\ud6a8\ud558\uc9c0 \uc54a\uc2b5\ub2c8\ub2e4. \uac12\uc740 1.0.1\uc774\uc5b4\uc57c \ud569\ub2c8\ub2e4. \n\uac12: {1} " }, {
        EventMessages.LOG_INVALID_GLOBAL_INSTANCE_ID_LENGTH_EXC_, "IWAT0206E \uc9c0\uc815\ud55c Common Base Event \ud2b9\uc131\uc5d0 \uc788\ub294 ID\uc758 \uae38\uc774\uac00 32 - 64\uc790\uc758 \uc720\ud6a8 \ubc94\uc704 \ubc16\uc5d0 \uc788\uc2b5\ub2c8\ub2e4. \n\ud2b9\uc131: {0} \n\uac12: {1} " }, {
        EventMessages.LOG_INVALID_LENGTH_EXC_, "IWAT0207E \uc9c0\uc815\ub41c Common Base Event \ud2b9\uc131\uc5d0 \uc788\ub294 \uac12\uc758 \uae38\uc774\uac00 \ucd5c\ub300 \ubb38\uc790 \uc218\ub97c \ucd08\uacfc\ud588\uc2b5\ub2c8\ub2e4. \n\ud2b9\uc131: {0} \n\uac12: {1} \n\uae38\uc774: {2} \n\ucd5c\ub300 \ubb38\uc790 \uc218: {3} " }, {
        EventMessages.LOG_INVALID_LENGTH_RANGE_EXC_, "IWAT0208E \uc9c0\uc815\ub41c Common Base Event \ud2b9\uc131\uc5d0 \uc788\ub294 \uac12\uc758 \uae38\uc774\uac00 \uc720\ud6a8 \ubc94\uc704 \ubc16\uc5d0 \uc788\uc2b5\ub2c8\ub2e4. \n\ud2b9\uc131: {0} \n\uac12: {1} \n\uae38\uc774: {2} \n\uc720\ud6a8 \uae38\uc774 \ubc94\uc704: {3} " }, {
        EventMessages.LOG_MISSING_ATTRIBUTES_EXC_, "IWAT0209E \uc9c0\uc815\ud55c \ud2b9\uc131\uc774 \ubaa8\ub450 \uc788\uac70\ub098 \ubaa8\ub450 \uc5c6\uc5b4\uc57c \ud569\ub2c8\ub2e4. \n\ud2b9\uc131: {0} " }, {
        EventMessages.LOG_INCONSISTENT_ATTRIBUTES_EXC_, "IWAT0210E Common Base Event\uc5d0 \uc788\ub294 {0} \ud2b9\uc131\uc758 \uac12\uc774 {1}\uc774\uba74 \uc9c0\uc815\ud55c \ud2b9\uc131 \ubaa9\ub85d\uc774 \uc5c6\uc5b4\uc57c \ud569\ub2c8\ub2e4. \n\ubaa9\ub85d: {2} " }, {
        EventMessages.LOG_CATEGORY_MISMATCH_EXC_, "IWAT0211E {0} \ud2b9\uc131\uc758 \uac12\uc774 situationType \ud2b9\uc131\uc5d0\uc11c \ucc38\uc870\ud558\ub294 \uc624\ube0c\uc81d\ud2b8 \ud074\ub798\uc2a4\uc640 \uc77c\uce58\ud558\uc9c0 \uc54a\uc2b5\ub2c8\ub2e4. \n\uac12: {1} \n\uc624\ube0c\uc81d\ud2b8 \ud074\ub798\uc2a4: {2}." }, {
        EventMessages.LOG_COMPONENT_IDENTIFICATION_INVALID_LOCATION_TYPE_EXC_, "IWAT0212E [{0}](\uc774)\ub77c\ub294 \uad6c\uc131\uc694\uc18c\ub97c \uac00\uc9c4 \uad6c\uc131\uc694\uc18c ID\uac00 \uc720\ud6a8\ud558\uc9c0 \uc54a\uc740 \uc720\ud615\uc744 \uac16\uace0 \uc788\uc2b5\ub2c8\ub2e4. [{1}]" }, {
	    EventMessages.LOG_EVENT_SAX_PARSER_UNEXPECTED_XML_ELEMENT_EXC_, "Unexpected element ''{0}'' at line {1}, column {2}." }, {
	    EventMessages.LOG_EVENT_SAX_PARSER_INCORRECT_XML_ELEMENT_EXC_ , "Expected element ''{0}'' , but found element ''{1}'' at line {2}, column {3}."}
    };
}

==> hyades.source_3.0.2_20050225_1641.zip: org/eclipse/hyades/logging/events/cbe/util/EventMessages_ko.java <==
package org.eclipse.hyades.logging.events.cbe.util;

import java.util.ListResourceBundle;
import org.eclipse.hyades.logging.events.cbe.util.EventMessages;

/**********************************************************************
 * Copyright (c) 2004 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

/**
 * Korean resource bundle.
 * 
 * @author Paul E. Slauenwhite
 * @version 1.0.1
 * @since 1.0.1
 */
public class EventMessages_ko extends ListResourceBundle {

    /**************************************************************************
    * Implements java.util.ListResourceBundle.getContents().
    * @see java.util.ListResourceBundle#getContents
    **************************************************************************/

    public Object[][] getContents() {
        return contents_;
    }

    /**************************************************************************
    * Resource table
    **************************************************************************/
    private final static Object[][] contents_ = { { EventMessages.LOG_INVALID_JNDI_REFERENCE_EXC_, "IWAT0187E \uc9c0\uc815\ub41c JNDI \uc774\ub984\uc5d0\uc11c \ud655\ubcf4\ud55c \ucc38\uc870\uac00 \uc774\ubca4\ud2b8 \ud329\ud1a0\ub9ac\uc5d0 \ub300\ud55c \ucc38\uc870\uac00 \uc544\ub2d9\ub2c8\ub2e4.\nJNDI \uc774\ub984: {0}" }, {
        EventMessages.LOG_FAILED_TO_SERIALIZE_CONTENT_HANDLER_EXC_, "IWAT0188E \uc774\ubca4\ud2b8 \ub0b4\uc6a9 \ud578\ub4e4\ub7ec\ub97c 2\uc9c4 \ud615\uc2dd\uc73c\ub85c \ubcc0\ud658\ud560 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4.\n\ucd94\uac00 \uc815\ubcf4(\uc788\ub294 \uacbd\uc6b0): {0}" }, {
        EventMessages.LOG_FAILED_TO_DESERIALIZE_CONTENT_HANDLER_EXC_, "IWAT0189E 2\uc9c4 \ud615\uc2dd\uc5d0\uc11c \uc774 JNDI \uc774\ub984\uc73c\ub85c \ucc38\uc870\ud558\ub294 \uc774\ubca4\ud2b8 \ub0b4\uc6a9 \ud578\ub4e4\ub7ec\ub85c \ub2e4\uc2dc \ubcc0\ud658\ud560 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4. \nJNDI \uc774\ub984: {0} \n\ucd94\uac00 \uc815\ubcf4(\uc788\uc744 \uacbd\uc6b0): {1}" }, {
        EventMessages.LOG_INVALID_GLOBAL_INSTANCE_ID_EXC_, "IWAT0190E \uc9c0\uc815\ub41c Common Base Event \ud2b9\uc131\uc758 \uc774\ubca4\ud2b8 ID\ub294 \uc601\ubb38\uc790\ub85c \uc2dc\uc791\ud574\uc57c \ud569\ub2c8\ub2e4. \n\ud2b9\uc131: {0} \nID: {1} " }, {
        EventMessages.LOG_VALUE_ARRAY_SIZE_MISMATCH_EXC_, "IWAT0191E \uc9c0\uc815\ub41c \ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c\uac00 \ud574\ub2f9 \uac12 \ubc30\uc5f4 \uc548\uc5d0 \ud558\ub098\uc758 \uc694\uc18c\ub9cc \ud544\uc694\ud55c \uc720\ud615\uc774\ub098 \uc5ec\ub7ec \uac1c\uc758 \uac12\uc774 \uc788\uc2b5\ub2c8\ub2e4. \n\ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c: {1}\n\uc720\ud615: {2} \n\uac12\uc758 \uc218: {0} " }, {
        EventMessages.LOG_INVALID_TYPE_CONVERSION_EXC_, "IWAT0192E \ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c\uc758 \uac12\uc744 \uc9c0\uc815\ud55c \uc720\ud615\uc73c\ub85c \ubcc0\ud658\ud560 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4. \n\ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c: {2} \n\uac12: {0} \n\uc720\ud615: {1}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_TYPE_EXC_, "IWAT0193E \ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c\uc5d0 \uc720\ud6a8\ud558\uc9c0 \uc54a\uc740 \uc694\uc18c\uac00 \uc788\uc2b5\ub2c8\ub2e4. \n\ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c: {0}\n\uc720\ud615: {1}" }, {
        EventMessages.LOG_EXTENDED_DATA_VALUE_NULL_EXC_, "IWAT0194E \ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c\uc5d0 \ub110\uac12\uc774 \ub4e4\uc5b4 \uc788\uc2b5\ub2c8\ub2e4. \uc720\ud615\uc774 \ubc30\uc5f4\uc774\uba74 \ud558\ub098 \uc774\uc0c1\uc758 \uc694\uc18c\uac00 \ub110(null)\uc785\ub2c8\ub2e4. \n\ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c: {0} \n\uc720\ud615: {1} " }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_BOOLEAN_EXC_, "IWAT0195E \ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c\uc5d0 \uc720\ud6a8\ud558\uc9c0 \uc54a\uc740 \ubd80\uc6b8 \ubb38\uc790\uc5f4\uc774 \ub4e4\uc5b4 \uc788\uc2b5\ub2c8\ub2e4. \n\ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c: {0}\n\uc720\ud615: {1} \n\ubb38\uc790\uc5f4: {2}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_DATE_EXC_, "IWAT0196E \ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c\uc5d0 \uc720\ud6a8\ud558\uc9c0 \uc54a\uc740 dateTime \ubb38\uc790\uc5f4\uc774 \ub4e4\uc5b4 \uc788\uc2b5\ub2c8\ub2e4. \n\ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c: {0}\nType: {1}\ndateTime \ubb38\uc790\uc5f4: {2}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_HEX_BINARY_1_EXC_, "IWAT0197E \ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c\uc758 hexValue \ud2b9\uc131 \uc694\uc18c\uc5d0\ub294 \uc9dd\uc218 \uac1c\uc758 \ubb38\uc790\uac00 \ub4e4\uc5b4 \uc788\uc5b4\uc57c \ud569\ub2c8\ub2e4. \n\ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c: {0} \n\uc720\ud615: {1} \n\uac12: {2} " }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_HEX_BINARY_2_EXC_, "IWAT0198E \ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c\uc758 hexValue \ud2b9\uc131\uc5d0 16\uc9c4\uc774 \uc544\ub2cc \ubb38\uc790\uac00 \ub4e4\uc5b4 \uc788\uc2b5\ub2c8\ub2e4. \n\ud655\uc7a5 \ub370\uc774\ud130 \uc694\uc18c \uc774\ub984: {0} \n\uc720\ud615: {1} \n\uac12: {2} \n\ube4416\uc9c4 \ubb38\uc790: {3} " }, {
        EventMessages.LOG_INVALID_SITUATION_TYPE_EXC_, "IWAT0199E \uc9c0\uc815\ub41c \ud2b9\uc131\uc758 \uac12\uc774 \uc720\ud6a8\ud558\uc9c0 \uc54a\uc2b5\ub2c8\ub2e4. \n\ud2b9\uc131: {0} \n\uac12: {1} \n\uc720\ud6a8\uac12: {2} " }, {
        EventMessages.LOG_INVALID_CREATION_TIME_EXC_, "IWAT0200E \uc9c0\uc815\ub41c \ud2b9\uc131\uc758 dateTime \uac12\uc744 \uad6c\ubb38 \ubd84\uc11d\ud560 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4. \n\ud2b9\uc131: {0} \n\uac12: {1} " }, {
        EventMessages.LOG_INVALID_LIST_ELEMENT_LENGTH_EXC_, "IWAT0201E \uc9c0\uc815\ub41c \ud2b9\uc131\uc5d0 \uc788\ub294 \uc694\uc18c \uae38\uc774\uac00 \ucd5c\ub300 \ubb38\uc790 \uc218\ub97c \ucd08\uacfc\ud569\ub2c8\ub2e4. \n\ud2b9\uc131: {1} \n\uc694\uc18c: {0} \n\ucd5c\ub300 \uae38\uc774: {2} " }, {
        EventMessages.LOG_VALUE_OUT_OF_RANGE_EXC_, "IWAT0202E \ud2b9\uc131 \uac12\uc774 \uc720\ud6a8\ud55c \ubc94\uc704 \ubc16\uc5d0 \uc788\uc2b5\ub2c8\ub2e4. \n\ud2b9\uc131: {1} \n\uac12: {0} \n\uc720\ud6a8 \ubc94\uc704: {2} - {3} " }, {
        EventMessages.LOG_MISSING_REQUIRED_ATTRIBUTE_EXC_, "IWAT0203E Common Base Event\uc5d0 \ud544\uc218 \ud2b9\uc131\uc774 \ub204\ub77d\ub418\uc5c8\uc2b5\ub2c8\ub2e4. \n\ud2b9\uc131: {0} " }, {
        EventMessages.LOG_MUTUALLY_EXCLUSIVE_ATTRIBUTES_EXC_, "IWAT0204E Common Base Event\uc5d0 \ud568\uaed8 \uc0ac\uc6a9\ud560 \uc218 \uc5c6\ub294 \ud2b9\uc131\uc774 \uc788\uc2b5\ub2c8\ub2e4. \n\ud2b9\uc131 1: {0} \n\ud2b9\uc131 2: {1} " }, {
        EventMessages.LOG_INVALID_VERSION_EXC_, "IWAT0205E {0} \ud2b9\uc131\uc758 \ubc84\uc804\uc774 \uc720\ud6a8\ud558\uc9c0 \uc54a\uc2b5\ub2c8\ub2e4. \uac12\uc740 1.0.1\uc774\uc5b4\uc57c \ud569\ub2c8\ub2e4. \n\uac12: {1} " }, {
        EventMessages.LOG_INVALID_GLOBAL_INSTANCE_ID_LENGTH_EXC_, "IWAT0206E \uc9c0\uc815\ud55c Common Base Event \ud2b9\uc131\uc5d0 \uc788\ub294 ID\uc758 \uae38\uc774\uac00 32 - 64\uc790\uc758 \uc720\ud6a8 \ubc94\uc704 \ubc16\uc5d0 \uc788\uc2b5\ub2c8\ub2e4. \n\ud2b9\uc131: {0} \n\uac12: {1} " }, {
        EventMessages.LOG_INVALID_LENGTH_EXC_, "IWAT0207E \uc9c0\uc815\ub41c Common Base Event \ud2b9\uc131\uc5d0 \uc788\ub294 \uac12\uc758 \uae38\uc774\uac00 \ucd5c\ub300 \ubb38\uc790 \uc218\ub97c \ucd08\uacfc\ud588\uc2b5\ub2c8\ub2e4. \n\ud2b9\uc131: {0} \n\uac12: {1} \n\uae38\uc774: {2} \n\ucd5c\ub300 \ubb38\uc790 \uc218: {3} " }, {
        EventMessages.LOG_INVALID_LENGTH_RANGE_EXC_, "IWAT0208E \uc9c0\uc815\ub41c Common Base Event \ud2b9\uc131\uc5d0 \uc788\ub294 \uac12\uc758 \uae38\uc774\uac00 \uc720\ud6a8 \ubc94\uc704 \ubc16\uc5d0 \uc788\uc2b5\ub2c8\ub2e4. \n\ud2b9\uc131: {0} \n\uac12: {1} \n\uae38\uc774: {2} \n\uc720\ud6a8 \uae38\uc774 \ubc94\uc704: {3} " }, {
        EventMessages.LOG_MISSING_ATTRIBUTES_EXC_, "IWAT0209E \uc9c0\uc815\ud55c \ud2b9\uc131\uc774 \ubaa8\ub450 \uc788\uac70\ub098 \ubaa8\ub450 \uc5c6\uc5b4\uc57c \ud569\ub2c8\ub2e4. \n\ud2b9\uc131: {0} " }, {
        EventMessages.LOG_INCONSISTENT_ATTRIBUTES_EXC_, "IWAT0210E Common Base Event\uc5d0 \uc788\ub294 {0} \ud2b9\uc131\uc758 \uac12\uc774 {1}\uc774\uba74 \uc9c0\uc815\ud55c \ud2b9\uc131 \ubaa9\ub85d\uc774 \uc5c6\uc5b4\uc57c \ud569\ub2c8\ub2e4. \n\ubaa9\ub85d: {2} " }, {
        EventMessages.LOG_CATEGORY_MISMATCH_EXC_, "IWAT0211E {0} \ud2b9\uc131\uc758 \uac12\uc774 situationType \ud2b9\uc131\uc5d0\uc11c \ucc38\uc870\ud558\ub294 \uc624\ube0c\uc81d\ud2b8 \ud074\ub798\uc2a4\uc640 \uc77c\uce58\ud558\uc9c0 \uc54a\uc2b5\ub2c8\ub2e4. \n\uac12: {1} \n\uc624\ube0c\uc81d\ud2b8 \ud074\ub798\uc2a4: {2}." }, {
        EventMessages.LOG_COMPONENT_IDENTIFICATION_INVALID_LOCATION_TYPE_EXC_, "IWAT0212E [{0}](\uc774)\ub77c\ub294 \uad6c\uc131\uc694\uc18c\ub97c \uac00\uc9c4 \uad6c\uc131\uc694\uc18c ID\uac00 \uc720\ud6a8\ud558\uc9c0 \uc54a\uc740 \uc720\ud615\uc744 \uac16\uace0 \uc788\uc2b5\ub2c8\ub2e4. [{1}]" }, {
	    EventMessages.LOG_EVENT_SAX_PARSER_UNEXPECTED_XML_ELEMENT_EXC_, "Unexpected element ''{0}'' at line {1}, column {2}." }, {
		EventMessages.LOG_EVENT_SAX_PARSER_INCORRECT_XML_ELEMENT_EXC_ , "Expected element ''{0}'' , but found element ''{1}'' at line {2}, column {3}."}, {
		EventMessages.LOG_EVENT_SAX_PARSER_INVALID_XML_ATTRIBUTE_EXC_ , "IWAT0157E The ''{0}'' attribute contains the invalid value ''{1}'' at line {2}, column {3}."}
    };
}
